<?php

namespace Chemtech\Test\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Chemtech\Test\Forms\Condition as ConditionForm;
use Chemtech\Test\Http\Requests\ConditionResourceRequest;
use Chemtech\Test\Http\Resources\ConditionResource;
use Chemtech\Test\Http\Resources\ConditionsCollection;
use Chemtech\Test\Models\Condition;
use Chemtech\Test\Actions\ConditionAction;
use Chemtech\Test\Actions\ConditionActions;


/**
 * Resource controller class for condition.
 */
class ConditionResourceController extends BaseController
{

    /**
     * Initialize condition resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = ConditionForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('chemtech.test.modules'), 'test', guard_url('test'));
            return $next($request);
        });
    }

    /**
     * Display a list of condition.
     *
     * @return Response
     */
    public function index(ConditionResourceRequest $request)
    {
        $request = $request->all();
        $page = ConditionActions::run('paginate', $request);

        $data = new ConditionsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('test::condition.names'))
            ->view('test::condition.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display condition.
     *
     * @param Request $request
     * @param Model   $condition
     *
     * @return Response
     */
    public function show(ConditionResourceRequest $request, Condition $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConditionResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('test::condition.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('test::condition.show')
            ->output();
    }

    /**
     * Show the form for creating a new condition.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ConditionResourceRequest $request, Condition $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConditionResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('test::condition.name'))
            ->view('test::condition.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new condition.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ConditionResourceRequest $request, Condition $model)
    {
        try {
            $request = $request->all();
            $model = ConditionAction::run('store', $model, $request);
            $data = new ConditionResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('test::condition.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('test/condition/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/test/condition'))
                ->redirect();
        }

    }

    /**
     * Show condition for editing.
     *
     * @param Request $request
     * @param Model   $condition
     *
     * @return Response
     */
    public function edit(ConditionResourceRequest $request, Condition $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ConditionResource($model);
        // return view('test::condition.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('test::condition.name'))
            ->view('test::condition.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the condition.
     *
     * @param Request $request
     * @param Model   $condition
     *
     * @return Response
     */
    public function update(ConditionResourceRequest $request, Condition $model)
    {
        try {
            $request = $request->all();
            $model = ConditionAction::run('update', $model, $request);
            $data = new ConditionResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('test::condition.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('test/condition/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('test/condition/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the condition.
     *
     * @param Model   $condition
     *
     * @return Response
     */
    public function destroy(ConditionResourceRequest $request, Condition $model)
    {
        try {

            $request = $request->all();
            $model = ConditionAction::run('destroy', $model, $request);
            $data = new ConditionResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('test::condition.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('test/condition/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('test/condition/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
